Module identity

Module identity 

Structs

IdCommand

Enums

IdSubcommand
LayoutPreset
Storage layout presets for different ecosystems.

Functions

handle_id
Handles the id subcommand, accepting the specific subcommand details and the global configuration overrides passed from main.