Module register

Module register 

Constants

DEFAULT_REGISTRY_URL
Default registry URL used when no explicit registry endpoint is configured.

Functions

handle_register
Publishes a local identity to a registry for public discovery.