Sign a Git commit with machine identity and OIDC binding.
Structs
- Sign
Commit Command - Sign a Git commit with the current identity.
Functions
- handle_
sign_ commit - Handle the sign-commit command.
Sign a Git commit with machine identity and OIDC binding.