pub struct DevicesSummary {
pub this_device: Option<String>,
pub linked: usize,
pub revoked: usize,
pub unanchored: usize,
pub expiring_soon: Vec<ExpiringDevice>,
pub devices_detail: Vec<DeviceStatus>,
}Expand description
Devices summary.
Fields
this_device: Option<String>The device the user is on right now (the root signing device). Always counted — “Devices: none” seconds after init authorized this machine reads as “setup didn’t take”.
linked: usizerevoked: usizeunanchored: usizeexpiring_soon: Vec<ExpiringDevice>devices_detail: Vec<DeviceStatus>Trait Implementations
Sourceimpl Debug for DevicesSummary
impl Debug for DevicesSummary