Module pubkey_cache

Module pubkey_cache 

Public key cache for passphrase-free signing.

This module caches public keys in ~/.auths/pubkeys/<alias>.pub to enable truly passphrase-free signing after first use. The agent can use these cached public keys to verify which key to use for signing without needing to decrypt the private key.

Functions

cache_pubkey
Cache a public key for the given alias.
clear_all_cached_pubkeys
Clear all cached public keys.
clear_cached_pubkey
Clear the cached public key for the given alias.
get_cached_pubkey
Get a cached public key for the given alias.