clear_cached_pubkey

Function clear_cached_pubkey 

pub fn clear_cached_pubkey(alias: &str) -> Result<bool>
Clear the cached public key for the given alias.

This should be called when a key is deleted or rotated.

Arguments

  • alias - The key alias (e.g., “default”).

Returns

  • Ok(true) - If the cache was cleared.
  • Ok(false) - If no cache existed for this alias.
  • Err - If there’s an error deleting the cache file.