Module storage

Module storage 

Functions

discover_git_repo
Discovers a Git repository starting from the given path, walking up parent directories.
ensure_git_repo
Opens an existing Git repository or initializes a new one.
init_git_repo
Initializes a new Git repository at the given path.
open_git_repo
Opens an existing Git repository at the given path.
read_git_config
Reads a Git configuration value from the default config.