pub fn ensure_agent_running(quiet: bool) -> Result<bool>Expand description
Ensures the SSH agent is running, starting it if necessary.
Returns Ok(true) if the agent was already running, Ok(false) if it was started.
Returns an error if the agent could not be started.
This function can be called from commands that need the agent to be running before performing signing operations, enabling auto-start functionality.