pub enum DeviceSubcommand {
List {
include_revoked: bool,
},
Link {
identity_key_alias: String,
device_key_alias: String,
device_did: String,
payload: Option<PathBuf>,
schema: Option<PathBuf>,
expires_in_days: Option<i64>,
note: Option<String>,
capabilities: Option<Vec<String>>,
},
Revoke {
device_did: String,
identity_key_alias: String,
note: Option<String>,
},
Resolve {
device_did: String,
},
Pair(PairCommand),
VerifyAttestation(VerifyCommand),
Extend {
device_did: String,
days: i64,
identity_key_alias: String,
device_key_alias: String,
},
}Variants
List
List all authorized devices for the current identity.
Link
Authorize a new device to act on behalf of the identity.
Fields
Revoke
Revoke an existing device authorization using the identity key.
Resolve
Resolve a device DID to its controller identity DID.
Pair(PairCommand)
Link devices to your identity via QR code or short code.
VerifyAttestation(VerifyCommand)
Verify device authorization signatures (attestation).
Extend
Extend the expiration date of an existing device authorization.