Public key cache for passphrase-free signing.
This module caches public keys in ~/.auths/pubkeys/<alias>.pub to enable
truly passphrase-free signing after first use. The agent can use these
cached public keys to verify which key to use for signing without needing
to decrypt the private key.
Functions
- cache_
pubkey - Cache a public key for the given alias.
- clear_
all_ cached_ pubkeys - Clear all cached public keys.
- clear_
cached_ pubkey - Clear the cached public key for the given alias.
- get_
cached_ pubkey - Get a cached public key for the given alias.