Functions
- discover_
git_ repo - Discovers a Git repository starting from the given path, walking up parent directories.
- ensure_
git_ repo - Opens an existing Git repository or initializes a new one.
- init_
git_ repo - Initializes a new Git repository at the given path.
- open_
git_ repo - Opens an existing Git repository at the given path.
- read_
git_ config - Reads a Git configuration value from the default config.